%define	Summary	A simple file manager with built-in FTP support

Summary:	%{Summary}
Name:		FileRunner
Version:	2.5.1
Release:	%mkrel 19
License:	GPL+
Group:		File tools
URL:		http://www.cd.chalmers.se/~hch/filerunner.html
Source0:	http://www.cd.chalmers.se/~hch/FileRunner-2.5.1.tar.bz2
# 'Fix' build for Tcl 8.6 (this is the hacky way to fix TIP #330 as it
# uses interp->result to set as well as get results and I'm not smart
# enough to fix that usage) - AdamW 2008/12
Patch0:		FileRunner-2.5.1-tcl86.patch
Patch1:		FileRunner-2.5.1-link.patch
Requires:	tcl
Requires:	tk
BuildRequires:	tcl-devel
BuildRequires:	tk-devel
BuildRequires:	imagemagick
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
FileRunner shows you a recursive graphical directory menu of your 
entire file system tree, including a history and hotlist (like
bookmarks).  FileRunner can also be used to browse through FTP
directories as easily as normal directories.  FileRunner supports
many FTP functions (upload/download, delete, makedir, FTP through a
proxy, resume download, asynchronous file transfer, and more) and is 
very configurable and extensible.

%prep
%setup -q
%patch0 -p1 -b .tcl86
%patch1 -p0 -b .link

# http://qa.mandriva.com/show_bug.cgi?id=22193
find -type f | xargs perl -pi -e "s|\\\$glob\(doclib_fr\)|%{_docdir}/%{name}|g"

# cleanup
rm -f ext.so*

%build

# instead of maintaining a patch...
. %{_libdir}/tclConfig.sh
. %{_libdir}/tkConfig.sh

gcc %{optflags} -Wall -fPIC $TCL_INCLUDE_SPEC -I$TK_SRC_DIR -c -o ext.o ext.c
gcc %{optflags} %{ldflags} -shared -Wl,-soname,ext.so -o ext.so ext.o -ltcl

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{tcl_sitearch}/%{name}/bitmaps
mkdir -p %{buildroot}%{_bindir}

cp -a bitmaps/* %{buildroot}%{tcl_sitearch}/%{name}/bitmaps
cp -a *.tcl %{buildroot}%{tcl_sitearch}/%{name}
cp -a ext.so %{buildroot}%{tcl_sitearch}/%{name}/ext.so
cp -a fr.gif %{buildroot}%{tcl_sitearch}/%{name}
cp -a icon.xpm %{buildroot}%{tcl_sitearch}/%{name}
cp -a tclIndex %{buildroot}%{tcl_sitearch}/%{name}

install -m755 fr %{buildroot}%{tcl_sitearch}/%{name}/fr
install -m755 frcolor %{buildroot}%{tcl_sitearch}/%{name}/frcolor
install -m755 frftp %{buildroot}%{tcl_sitearch}/%{name}/frftp

ln -s %{tcl_sitearch}/%{name}/fr %{buildroot}%{_bindir}/fr

# Mandriva Icons
mkdir -p %{buildroot}%{_iconsdir}/hicolor/{16x16,32x32,48x48}/apps

convert icon.xpm -resize 16x16  %{buildroot}%{_iconsdir}/hicolor/16x16/apps/%{name}.png
convert icon.xpm -resize 32x32  %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
convert icon.xpm -resize 48x48  %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/mageia-%{name}.desktop << EOF
[Desktop Entry]
Name=%{name}
Comment=%{Summary}
Exec=%{tcl_sitearch}/%{name}/fr
Icon=%{name}
Terminal=false
Type=Application
Categories=Network;FileTransfer;
EOF

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc COPYING FAQ HISTORY QuickStart.txt README Tips.txt Users_Guide.txt 
%{tcl_sitearch}/%{name}
%{_bindir}/fr
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_datadir}/applications/mageia-%{name}.desktop





%changelog
* Tue Mar 08 2011 ennael <ennael> 2.5.1-19.mga1
+ Revision: 66646
- fix desktop file name

* Tue Mar 08 2011 ennael <ennael> 2.5.1-18.mga1
+ Revision: 66570
- clean spec file
- imported package FileRunner


* Mon Jan 03 2011 Funda Wang <fwang@mandriva.org> 2.5.1-18mdv2011.0
+ Revision: 627685
- tighten BR

* Thu Dec 09 2010 Jani Välimaa <wally@mandriva.org> 2.5.1-17mdv2011.0
+ Revision: 617232
- require tk (mdv#61885)

* Wed Dec 08 2010 Oden Eriksson <oeriksson@mandriva.com> 2.5.1-16mdv2011.0
+ Revision: 616414
- the mass rebuild of 2010.0 packages

* Thu Sep 10 2009 Thierry Vignaud <tv@mandriva.org> 2.5.1-15mdv2010.0
+ Revision: 437541
- rebuild

  + Oden Eriksson <oeriksson@mandriva.com>
    - lowercase ImageMagick

* Fri Dec 05 2008 Adam Williamson <awilliamson@mandriva.org> 2.5.1-14mdv2009.1
+ Revision: 310863
- rebuild for new tcl
- drop old category from menu
- fd.o icons
- move to new location per policy
- %%buildroot not $RPM_BUILD_ROOT
- no need to add /usr/X11/include any more
- adjust a substitution for unversioned docdir
- kludge build for tcl 8.6
- new license policy

* Thu Jul 24 2008 Thierry Vignaud <tv@mandriva.org> 2.5.1-13mdv2009.0
+ Revision: 245147
- rebuild
- drop old menu

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 2.5.1-11mdv2008.1
+ Revision: 136415
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - buildrequires X11-devel instead of XFree86-devel
    - import FileRunner


* Sun Jul 30 2006 Oden Eriksson <oeriksson@mandriva.com> 2.5.1-11mdv2007.0
- fix the ext.so file
- fix the icons

* Sun Jul 30 2006 Oden Eriksson <oeriksson@mandriva.com> 2.5.1-10mdv2007.0
- fix #22193
- added lib64 fixes
- fix xdg menu

* Mon Jun 19 2006 Lenny Cartier <lenny@mandriva.com> 2.5.1-9mdv2007.0
- use mkrel

* Wed Jan 04 2006 Oden Eriksson <oeriksson@mandriva.com> 2.5.1-8mdk
- rebuilt against soname aware deps (tcl/tk)
- fix deps

* Wed Sep  1 2004 Warly <warly@mandrakesoft.com> 2.5.1-7mdk
- rebuild

* Fri Apr 23 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 2.5.1-6mdk
- fix buildrequires

* Sat Jul 12 2003 Per yvind Karlsen <peroyvind@sintrax.net> 2.5.1-5mdk
- rebuild
- fix unowned dir
- fix menu item
- compile with $RPM_OPT_FLAGS

* Thu Jul 19 2001 Stefan van der Eijk <stefan@eijk.nu> 2.5.1-4mdk
- BuildRequires:	tk XFree86-devel

* Tue Jan 16 2001 David BAUDENS <baudens@mandrakesoft.com> 2.5.1-3mdk
- BuildRequires: tk
- s/Copyright/License
- Build with gcc-2.96 and glibc-2.2.1

* Mon Aug 21 2000 Vincent Saugey <vince@mandrakesoft.com> 2.5.1-2mdk
- BM
- Macros

* Tue Jun 20 2000 Christopher Molnar <molnarc@mandrakesoft.com> 2.5.1-1mdk
- Updated version

* Wed Apr 19 2000 Christopher Molnar <molnarc@mandrakesoft.com> 2.5-3mdk
- fixed missing menu entries.

* Wed Apr 05 2000 Christopher Molnar <molnarc@mandrakesoft.com> 2.5-2mdk
- updated group for 7.1

* Wed Dec 08 1999 Jerome Dumonteil <jd@mandrakesoft.com>
- mandrake adaptation

* Sun Aug 15 1999 Dale Lovelace <dale@redhat.com>
- added filerunner.wmconfig

* Fri Jun 25 1999 Tim Powers <timp@redhat.com>
- rebuilt for 6.1

* Mon Apr 12 1999 Michael Maher <mike@redhat.com>
- updated 6.0 

* Wed Oct 06 1998 Michael Maher <mike@redhat.com>
- upgraded package
- cleaned up spec file

* Tue May 19 1998 Cristian Gafton <gafton@redhat.com>
- upgraded to 2.4.2

* Mon Feb 16 1998 Otto Hammersmith <otto@redhat.com>
- fixed description

* Thu Jan 08 1998 Mike Wangsmo <wanger@redhat.com>
- initial build
